/*
 *  This file is part of RawTherapee.
 *
 *  Copyright (c) 2004-2010 Gabor Horvath <hgabor@rawtherapee.com>
 *
 *  RawTherapee is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  RawTherapee is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with RawTherapee.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef _RTIMAGE_
#define _RTIMAGE_

#include <gtkmm.h>
#include "options.h"

class RTImage : public Gtk::Image
{
public:
    RTImage(Glib::ustring fileName, Glib::ustring rtlFileName = "");
    static void setPaths(Options &opt);
    static void updateImages();
    void changeImage(Glib::ustring &newImage);
    static Glib::ustring findIconAbsolutePath(const Glib::ustring &iconFName);
};

#endif
